==> haskell-cassava-0.5.2.0-129-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cassava
version:              0.5.2.0
visibility:           public
id:                   cassava-0.5.2.0-GI6IwyuXnI6GGSiKrTd0G1
key:                  cassava-0.5.2.0-GI6IwyuXnI6GGSiKrTd0G1
license:              BSD-3-Clause
copyright:
    (c) 2012 Johan Tibell
    (c) 2012 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           hvr@gnu.org
author:               Johan Tibell
homepage:             https://github.com/hvr/cassava
synopsis:             A CSV parsing and encoding library
description:
    @cassava@ is a library for parsing and encoding [RFC 4180](https://tools.ietf.org/html/rfc4180)
    compliant [comma-separated values (CSV)](https://en.wikipedia.org/wiki/Comma-separated_values) data,
    which is a textual line-oriented format commonly used for exchanging tabular data.

    @cassava@'\''s API includes support for

    - Index-based record-conversion
    - Name-based record-conversion
    - Typeclass directed conversion of fields and records
    - Built-in field-conversion instances for standard types
    - Customizable record-conversion instance derivation via GHC generics
    - Low-level [bytestring](https://hackage.haskell.org/package/bytestring) builders (see "Data.Csv.Builder")
    - Incremental decoding and encoding API (see "Data.Csv.Incremental")
    - Streaming API for constant-space decoding (see "Data.Csv.Streaming")

    Moreover, this library is designed to be easy to use; for instance, here'\''s a
    very simple example of encoding CSV data:

    >>> Data.Csv.encode [("John",27),("Jane",28)]
    "John,27\r\nJane,28\r\n"

    Please refer to the documentation in "Data.Csv" and the included [README](#readme) for more usage examples.

category:             Text, Web, CSV
abi:                  ca0a7c22e9da7d26a3d96dfed24536fe
exposed:              True
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming

hidden-modules:
    Data.Csv.Conversion Data.Csv.Conversion.Internal Data.Csv.Encoding
    Data.Csv.Types Data.Csv.Util

import-dirs:          /usr/lib/ghc-8.10.4/site-local/cassava-0.5.2.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/cassava-0.5.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/cassava-0.5.2.0
hs-libraries:         HScassava-0.5.2.0-GI6IwyuXnI6GGSiKrTd0G1
depends:
    Only-0.1-Hmiu2AVa9qJ6EI7MrgJvvl array-0.5.4.0
    attoparsec-0.14.1-Dlm5EB3n5xmG4Iku2w73OX base-4.14.1.0
    bytestring-0.10.12.0 containers-0.6.2.1 deepseq-1.4.4.0
    hashable-1.3.1.0-4EsGp1K7uOu2cACWuCidz3
    scientific-0.3.6.2-ErrVUcpZzeLEYjP4jqSF4S text-1.2.4.1
    text-short-0.1.3-IQcBebyzUIKHjvcsFIWxWJ transformers-0.5.6.2
    unordered-containers-0.2.13.0-4AoMTstniRpGNa4LW5BINH
    vector-0.12.3.0-H4rWOat9KWYJKIFglDYjhy

haddock-interfaces:   /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html:         /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-0.5.2.0-130-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cassava
version:              0.5.2.0
visibility:           public
id:                   cassava-0.5.2.0-G9nz0OMPLqkD8B7RwNz6cg
key:                  cassava-0.5.2.0-G9nz0OMPLqkD8B7RwNz6cg
license:              BSD-3-Clause
copyright:
    (c) 2012 Johan Tibell
    (c) 2012 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           hvr@gnu.org
author:               Johan Tibell
homepage:             https://github.com/hvr/cassava
synopsis:             A CSV parsing and encoding library
description:
    @cassava@ is a library for parsing and encoding [RFC 4180](https://tools.ietf.org/html/rfc4180)
    compliant [comma-separated values (CSV)](https://en.wikipedia.org/wiki/Comma-separated_values) data,
    which is a textual line-oriented format commonly used for exchanging tabular data.

    @cassava@'\''s API includes support for

    - Index-based record-conversion
    - Name-based record-conversion
    - Typeclass directed conversion of fields and records
    - Built-in field-conversion instances for standard types
    - Customizable record-conversion instance derivation via GHC generics
    - Low-level [bytestring](https://hackage.haskell.org/package/bytestring) builders (see "Data.Csv.Builder")
    - Incremental decoding and encoding API (see "Data.Csv.Incremental")
    - Streaming API for constant-space decoding (see "Data.Csv.Streaming")

    Moreover, this library is designed to be easy to use; for instance, here'\''s a
    very simple example of encoding CSV data:

    >>> Data.Csv.encode [("John",27),("Jane",28)]
    "John,27\r\nJane,28\r\n"

    Please refer to the documentation in "Data.Csv" and the included [README](#readme) for more usage examples.

category:             Text, Web, CSV
abi:                  e289dec169ebc6e82a65ba7c2e3678d8
exposed:              True
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming

hidden-modules:
    Data.Csv.Conversion Data.Csv.Conversion.Internal Data.Csv.Encoding
    Data.Csv.Types Data.Csv.Util

import-dirs:          /usr/lib/ghc-8.10.4/site-local/cassava-0.5.2.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/cassava-0.5.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/cassava-0.5.2.0
hs-libraries:         HScassava-0.5.2.0-G9nz0OMPLqkD8B7RwNz6cg
depends:
    Only-0.1-Hmiu2AVa9qJ6EI7MrgJvvl array-0.5.4.0
    attoparsec-0.14.1-DGdxWuqth0ECkVhd5culC1 base-4.14.1.0
    bytestring-0.10.12.0 containers-0.6.2.1 deepseq-1.4.4.0
    hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh
    scientific-0.3.6.2-4bcqTnRqWzl33Suoc5baAM text-1.2.4.1
    text-short-0.1.3-2pw4OnzYRv523NNf6Z2TY transformers-0.5.6.2
    unordered-containers-0.2.13.0-6CorcJuUNAZJ43lHhm1xtn
    vector-0.12.3.0-IwaLbQErzPq95Qm3ml0M2u

haddock-interfaces:   /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html:         /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
